// (C) 2025 GoodData Corporation
import React from "react";
import cx from "classnames";
import { FormattedMessage, useIntl } from "react-intl";
import { makeLinearKeyboardNavigation, useIdPrefixed } from "@gooddata/sdk-ui-kit";
import { useAutoupdateRef } from "@gooddata/sdk-ui";
import { LegendSeriesContextStore, useLegendSeriesContextValue } from "./context.js";
export const LegendSeries = React.forwardRef(function LegendSeries({ series, label, style, children, onToggleItem, className }, ref) {
    const { formatMessage } = useIntl();
    const [focusedIndex, setFocusedIndex] = React.useState(0);
    const id = useIdPrefixed("LegendSeries");
    React.useEffect(() => {
        setFocusedIndex(0);
    }, [series.length]);
    const contextValue = useLegendSeriesContextValue({ series, id, focusedIndex });
    const { makeItemId, descriptionId } = contextValue;
    const keyDownDepsRef = useAutoupdateRef({
        focusedIndex,
        onToggleItem,
        series,
    });
    const handleKeyDown = React.useMemo(() => makeLinearKeyboardNavigation({
        onFocusNext: () => {
            const { series } = keyDownDepsRef.current;
            setFocusedIndex((prevIndex) => {
                const nextIndex = prevIndex + 1;
                if (nextIndex >= series.length) {
                    return 0;
                }
                return nextIndex;
            });
        },
        onFocusPrevious: () => {
            const { series } = keyDownDepsRef.current;
            setFocusedIndex((prevIndex) => {
                const nextIndex = prevIndex - 1;
                if (nextIndex < 0) {
                    return series.length - 1;
                }
                return nextIndex;
            });
        },
        onFocusFirst: () => {
            setFocusedIndex(0);
        },
        onFocusLast: () => {
            const { series } = keyDownDepsRef.current;
            setFocusedIndex(series.length - 1);
        },
        onSelect: () => {
            const { onToggleItem, focusedIndex, series } = keyDownDepsRef.current;
            onToggleItem(series[focusedIndex]);
        },
    }), [keyDownDepsRef]);
    return (React.createElement(LegendSeriesContextStore, { value: contextValue },
        React.createElement("div", { className: cx("series-wrapper legend-series-wrapper", className), role: "group", "aria-activedescendant": makeItemId(series[focusedIndex]), tabIndex: 0, onKeyDown: handleKeyDown },
            React.createElement("div", { className: "series legend-series", role: "list", "aria-label": label
                    ? formatMessage({ id: "properties.legend.series.named" }, { name: label })
                    : formatMessage({ id: "properties.legend.series.unnamed" }), style: style, ref: ref }, children),
            React.createElement("p", { id: descriptionId, className: "sr-only", role: "presentation" },
                React.createElement(FormattedMessage, { id: "properties.legend.series.item.description" })))));
});
//# sourceMappingURL=LegendSeries.js.map