// (C) 2007-2025 GoodData Corporation
import React from "react";
import cx from "classnames";
import noop from "lodash/noop.js";
import { LegendList } from "./LegendList.js";
import { Paging } from "./Paging.js";
import { BOTTOM, TOP } from "./PositionTypes.js";
import { calculateStaticLegend, ITEM_HEIGHT, STATIC_PAGING_HEIGHT } from "./helpers.js";
import { LegendLabelItem } from "./LegendLabelItem.js";
import { LegendSeries } from "./LegendSeries.js";
/**
 * @internal
 */
export const StaticLegend = React.memo(function StaticLegend({ buttonOrientation = "upDown", paginationHeight = STATIC_PAGING_HEIGHT, containerHeight, position, series, enableBorderRadius, shouldFillAvailableSpace, label, customComponent, isLabelVisible = true, onItemClick, onPageChanged, }) {
    const [page, setPage] = React.useState(1);
    const handleNextPage = React.useCallback(() => {
        setPage((currentPage) => {
            const newPage = currentPage + 1;
            onPageChanged?.(newPage);
            return newPage;
        });
    }, [onPageChanged]);
    const handlePreviousPage = React.useCallback(() => {
        setPage((currentPage) => {
            const newPage = currentPage - 1;
            onPageChanged?.(newPage);
            return newPage;
        });
    }, [onPageChanged]);
    const hasCustomComponent = customComponent != null;
    const shouldDisplayCustomComponent = page === 1 && hasCustomComponent;
    const columnNum = position === "dialog" ? 2 : 1;
    const labelHeight = label && isLabelVisible ? ITEM_HEIGHT : 0;
    const labelNode = label && isLabelVisible ? React.createElement(LegendLabelItem, { label: label }) : null;
    const contentHeight = containerHeight - labelHeight;
    const seriesCount = series.length;
    const { hasPaging, visibleItemsCount } = calculateStaticLegend(seriesCount, contentHeight, columnNum, paginationHeight);
    const usePaging = hasPaging || hasCustomComponent;
    const pagesCount = getPagesCount(series.length, visibleItemsCount, hasCustomComponent);
    const heightOfAvailableSpace = (visibleItemsCount / columnNum) * ITEM_HEIGHT;
    const heightOfVisibleItems = Math.min(visibleItemsCount / columnNum, seriesCount) * ITEM_HEIGHT;
    const seriesHeight = (shouldFillAvailableSpace ? heightOfAvailableSpace : heightOfVisibleItems) + labelHeight;
    const [start, end] = getPagingValues(page, visibleItemsCount, series.length, hasCustomComponent);
    const pagedSeries = series.slice(start, end);
    const visibleItemsFitOneColumn = shouldItemsFitOneColumn(visibleItemsCount, columnNum, pagedSeries.length);
    const classNames = cx("viz-legend", "static", `position-${position}`, {
        "no-width": !shouldDisplayCustomComponent && visibleItemsFitOneColumn,
    });
    // Without paging
    if (position === TOP || position === BOTTOM) {
        return (React.createElement("div", { className: classNames },
            React.createElement(LegendSeries, { series: series, label: label, onToggleItem: onItemClick ?? noop },
                React.createElement(LegendList, { enableBorderRadius: enableBorderRadius, series: series, onItemClick: onItemClick ?? noop }))));
    }
    return (React.createElement("div", { className: classNames },
        React.createElement(LegendSeries, { series: pagedSeries, label: label, style: { height: seriesHeight }, onToggleItem: onItemClick ?? noop },
            labelNode,
            shouldDisplayCustomComponent ? (customComponent) : (React.createElement(LegendList, { enableBorderRadius: enableBorderRadius, series: pagedSeries, onItemClick: onItemClick ?? noop }))),
        usePaging ? (React.createElement(Paging, { page: page, pagesCount: pagesCount, showNextPage: handleNextPage, showPrevPage: handlePreviousPage, buttonsOrientation: buttonOrientation })) : null));
});
const getPagesCount = (seriesLength, visibleItemsCount, hasCustomComponent) => {
    const defaultPagesCount = Math.ceil(seriesLength / visibleItemsCount);
    return hasCustomComponent ? defaultPagesCount + 1 : defaultPagesCount;
};
export const getPagingValues = (page, visibleItemsCount, seriesLength, hasCustomComponent) => {
    const start = hasCustomComponent ? (page - 2) * visibleItemsCount : (page - 1) * visibleItemsCount;
    const end = hasCustomComponent
        ? Math.min(visibleItemsCount * (page - 1), seriesLength)
        : Math.min(visibleItemsCount * page, seriesLength);
    return [start, end];
};
const shouldItemsFitOneColumn = (visibleItemsCount, columnNum, pagedSeriesLength) => visibleItemsCount / columnNum >= pagedSeriesLength;
//# sourceMappingURL=StaticLegend.js.map